<#  
.SYNOPSIS  
    Sets redirection from root and forces SSL settings
.DESCRIPTION  
    Redirects / to /owa and forces SSL on recommended vdirs
    Configures rights on web.config file for OAB
.PARAMETER URL
    Specifies the destination to redirect to
.PARAMETER ForceSSL
		Whether the Exchange specific virtual directories are set to require SSL. Default is $True
.NOTES  
    Version      : 1.0 - 04/26/2010 - initial version
    Rights Req'd : Local Server Admin
    Sch Task Req : No
    Exchange Ver : 2010
    Author       : Pat Richard, Exchange MVP
    Email        : pat@innervation.com
    Blog         : http://www.ucblogs.net/blogs/exchange
    Disclaimer   : Don't blame me if this breaks your stuff.
    Info Stolen  : 
.LINK  
	http://www.ucblogs.net/blogs/exchange/archive/2010/04/28/Redirecting-the-root-web-site-to-_2F00_owa-and-forcing-SSL-in-Exchange-2010.aspx
.EXAMPLE
	.\Set-Exchange2010RedirectSSL.ps1 -url "https://mail.ehloworld.com/owa"
.INPUTS
	None. You cannot pipe objects to this script.
#>

#Requires -Version 2.0

param(
	[Parameter(Mandatory = $true,valueFromPipeline=$true)][string] $url,
	[Parameter(Mandatory = $false,valueFromPipeline=$true)][string] $ForceSSL,
	[Parameter(Mandatory = $false,valueFromPipeline=$false)][string] $SetupRegistryPath,
	[Parameter(Mandatory = $false,valueFromPipeline=$false)][string] $SetupEntries,
	[Parameter(Mandatory = $false,valueFromPipeline=$false)][string] $InstallPath,
	[Parameter(Mandatory = $false,valueFromPipeline=$false)][string] $PathToFile,
	[Parameter(Mandatory = $false,valueFromPipeline=$false)][string] $backup
) #end param

Import-Module ServerManager
if ((Get-WindowsFeature web-http-redirect).installed -eq $false){
	Write-Host "`nInstalling web-http-redirect feature" -ForegroundColor green
	ServerManagerCMD -i web-http-redirect
}

function GetExchangeInstallPath
{
    # Get the root setup entires.
    $setupRegistryPath = "HKLM:\SOFTWARE\Microsoft\ExchangeServer\v14\Setup"
    $setupEntries = Get-ItemProperty $setupRegistryPath
    if($setupEntries -eq $null)
    {
        return $null
    }

    # Try to get the Install Path.
    $InstallPath = $setupEntries.MsiInstallPath
    return $InstallPath
} # end GetExchangeInstallPath

$PathToFile = (GetExchangeInstallPath)+"ClientAccess\OAB\web.config"

Set-Location "c:\Windows\System32\inetsrv"
Write-Host "Backing up current IIS configuration" -ForegroundColor green
$backup = "OWA Redirect Backup "+(get-date -format "MMddyyyy-hhmmss")
.\appcmd.exe ADD Backup $backup


Write-Host "`nConfiguring redirection to $url" -ForegroundColor green
.\appcmd set config "Default Web Site" /section:httpRedirect /childonly:true /enabled:true /destination:"$url"

if ($ForceSSL -ne $false){
	Write-Host "`nSetting SSL configuration" -ForegroundColor green
	.\appcmd set config "Default Web Site" /section:access /sslFlags:"" /commit:apphost

	.\appcmd set config "Default Web Site/Aspnet_Client" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Autodiscover" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/EWS" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/ECP" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Exchange" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Exchweb" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Microsoft-Server-ActiveSync" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/OWA" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "default web site/PowerShell" /section:access /sslFlags:"" /commit:apphost
	.\appcmd set config "default web site/OAB" /section:access /sslFlags:"" /commit:apphost
	.\appcmd set config "Default Web Site/Public" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
	.\appcmd set config "Default Web Site/Rpc" /section:access /sslFlags:Ssl /commit:apphost
	.\appcmd set config "Default Web Site/RpcWithCert" /section:access /sslFlags:"Ssl,Ssl128" /commit:apphost
}
if (Test-Path($PathToFile)){
	icacls $PathToFile /grant:R 'NT Authority\Authenticated Users:R'
}

Write-Host "`nRestarting IIS for configuration to take effect" -ForegroundColor green
iisreset